#ifndef RENDER_BYTES_H
#define RENDER_BYTES_H
#include <glib.h>
namespace pan {
  extern char* render_bytes (guint64);
}
#endif
